==> ada-cli-2.2.4.tgz: package/texts.js <==
'use strict'

const config = require('./lib/rc')().get()

const _ = require('lodash')
const async = require('async')

const ada = require('./lib/index.js')
const store = require('./lib/store.js')

const twilio = require('twilio')
const twilioClient = twilio(config.twilio.accountSid, config.twilio.authToken)

const express = require('express')
const bodyParser = require('body-parser')
const app = express()

// for debugging:
// const readline = require('readline')
// const rl = readline.createInterface({
//   input: process.stdin,
//   output: process.stdout
// })

app.use(bodyParser.urlencoded({ extended: false }))
app.listen(config.server.port)

app.post('/', (request, response) => {
  const from = request.body.From
  const body = request.body.Body
  console.log(from, body)

  const restart = ['restart', 'reset', '💣']
  if (_.includes(restart, body.trim().toLowerCase())) {
    return store.deleteState(from, () => mapResponseToAnswer('restart', from))
  }
  mapResponseToAnswer(body, from)
})

const sendResult = (telephoneNumber, result) => {
  const message = [result.summary]

  message.concat(result.conditionReports.map((condition) => {
    return `${condition.seriousnessAdvice}: ${condition.name}`
  }))

  sendText(telephoneNumber, message.join('\n'), () => {
    console.log('done 🎉')
  })
}

const mapResponseToAnswer = (response, telephoneNumber) => {
  store.getState(telephoneNumber, (err, state) => {
    if (!state) {
      console.log('!state ', telephoneNumber)
      return ask(telephoneNumber)
    }
    if (err) throw err
    if (state.answerType === 'TEXT') {
      console.log('state.answerType === TEXT')
      console.log('telephoneNumber ', telephoneNumber)
      console.log('response ', response)
      return ask(telephoneNumber, response)
    }

    response = response.replace(/[^0-9]+/gi, '')
    const highestResponse = state.answerOptions.length
    if (response > highestResponse || !response.length) {
      const warn = `Please enter a number from 1 - ${highestResponse}. Thanks <3 ️`
      return sendText(telephoneNumber, warn, () => {})
    }
    console.log('telephoneNumber ', telephoneNumber)
    console.log('state.answerOptions[response - 1] ', state.answerOptions[response - 1])
    return ask(telephoneNumber, state.answerOptions[response - 1])
  })
}

const ask = (telephoneNumber, answerObj) => {
  ada(telephoneNumber, answerObj, false, (err, question) => {
    if (err) throw err
    if (question.summary) return sendResult(telephoneNumber, question)
    if (question.isOver) return sendText(question.gibberish.join(' '))

    const send = []
    send.push(_.flattenDeep([].concat(question.question)).join(' '))

    if (question.answerType === 'SELECT') {
      send.push(question.answerOptions.map((answer, index) => {
        return `${++index}. ${answer.text || answer.patientName}`
      }).join('\n'))
    }

    async.eachSeries(send, sendText.bind(undefined, telephoneNumber), (err) => {
      if (err) console.error(err)
      // for debugging:
      //  rl.question('? ', (answer) => {
      //   mapResponseToAnswer(answer, '06604099366')
      //   rl.pause()
      // })
    })
  })
}

const sendText = (number, message, cb) => {
  // for debugging:
  // console.log(message)
  // cb()
  twilioClient.sendMessage({
    to: number,
    from: config.twilio.from,
    body: message
  }, (err, responseData) => {
    if (err) cb(err)
    console.log('Message ', responseData.status)
    cb()
  })
}

==> ada-cli-3.0.2.tgz: package/texts.js <==
'use strict'

const config = require('./lib/rc')().get()

const _ = require('lodash')
const async = require('async')

const ada = require('./lib/index.js')
const store = require('./lib/store.js')

const twilio = require('twilio')
const twilioClient = twilio(config.twilio.accountSid, config.twilio.authToken)

const express = require('express')
const bodyParser = require('body-parser')
const app = express()

// for debugging:
// const readline = require('readline')
// const rl = readline.createInterface({
//   input: process.stdin,
//   output: process.stdout
// })

app.use(bodyParser.urlencoded({ extended: false }))
app.listen(config.server.port)

app.post('/', (request, response) => {
  const from = request.body.From
  const body = request.body.Body
  console.log(from, body)

  const restart = ['restart', 'reset', '💣']
  if (_.includes(restart, body.trim().toLowerCase())) {
    return store.deleteState(from, () => mapResponseToAnswer('restart', from))
  }
  mapResponseToAnswer(body, from)
})

const sendResult = (telephoneNumber, result) => {
  const message = [result.summary]

  message.concat(result.conditionReports.map((condition) => {
    return `${condition.seriousnessAdvice}: ${condition.name}`
  }))

  sendText(telephoneNumber, message.join('\n'), () => {
    console.log('done 🎉')
  })
}

const mapResponseToAnswer = (response, telephoneNumber) => {
  store.getState(telephoneNumber, (err, state) => {
    if (!state) {
      console.log('!state ', telephoneNumber)
      return ask(telephoneNumber)
    }
    if (err) throw err
    if (state.answerType === 'TEXT') {
      console.log('state.answerType === TEXT')
      console.log('telephoneNumber ', telephoneNumber)
      console.log('response ', response)
      return ask(telephoneNumber, response)
    }

    response = response.replace(/[^0-9]+/gi, '')
    const highestResponse = state.answerOptions.length
    if (response > highestResponse || !response.length) {
      const warn = `Please enter a number from 1 - ${highestResponse}. Thanks <3 ️`
      return sendText(telephoneNumber, warn, () => {})
    }
    console.log('telephoneNumber ', telephoneNumber)
    console.log('state.answerOptions[response - 1] ', state.answerOptions[response - 1])
    return ask(telephoneNumber, state.answerOptions[response - 1])
  })
}

const ask = (telephoneNumber, answerObj) => {
  ada(telephoneNumber, answerObj, false, (err, question) => {
    if (err) throw err
    if (question.summary) return sendResult(telephoneNumber, question)
    if (question.isOver) return sendText(question.gibberish.join(' '))

    const send = []
    send.push(_.flattenDeep([].concat(question.question)).join(' '))

    if (question.answerType === 'SELECT') {
      send.push(question.answerOptions.map((answer, index) => {
        return `${++index}. ${answer.text || answer.patientName}`
      }).join('\n'))
    }

    async.eachOfSeries(send, sendText.bind(undefined, telephoneNumber), (err) => {
      if (err) console.error(err)
      // for debugging:
      //  rl.question('? ', (answer) => {
      //   mapResponseToAnswer(answer, '06604099366')
      //   rl.pause()
      // })
    })
  })
}

const sendText = (number, message, key, cb) => {
  // for debugging:
  // console.log(message)
  // cb()

  setTimeout(() => {
    twilioClient.sendMessage({
      to: number,
      from: config.twilio.from,
      body: message
    }, (err, responseData) => {
      if (err) cb(err)
      console.log('Message ', responseData.status)
      cb()
    }) }, !key ? 0 : 1000)
}
